globalVariables(
  c('hits',
    'value',
    'acf',
    'new_var',
    'variable',
    'variable_t',
    'contrib',
    'category',
    'calc',
    'day',
    'week',
    'month',
    'year',
    'number',
    'dim_rets',
    'coef',
    'se',
    't_stat',
    'parameter',
    'p_value',
    'adj_R2',
    'name',
    'trans_df',
    'func',
    'ts',
    'tail_window',
    'id_var',
    'temp_dv_var',
    'pool',
    '.'
  ))
